==> linkit_sharepoint-1.0.0.tar.gz: linkit_sharepoint/src/Plugin/Field/FieldType/DocumentItem.php <==
<?php

namespace Drupal\linkit_sharepoint\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Defines the 'linkit_sharepoint_document' field type.
 *
 * @FieldType(
 *   id = "linkit_sharepoint_document",
 *   label = @Translation("Sharepoint Document"),
 *   category = @Translation("General"),
 *   default_widget = "linkit_sharepoint_document",
 *   default_formatter = "linkit_sharepoint_document"
 * )
 */
class DocumentItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('value')->getValue();
    return $value === NULL || $value === '';
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['value'] = DataDefinition::create('string')
      ->setLabel(t('Text value'))
      ->setRequired(TRUE);
    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function getConstraints() {
    $constraints = parent::getConstraints();
    $constraint_manager = \Drupal::typedDataManager()->getValidationConstraintManager();

    $options['value']['Length']['max'] = 255;
    $constraints[] = $constraint_manager->create('ComplexData', $options);
    return $constraints;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    $columns = [
      'value' => [
        'type' => 'varchar',
        'not null' => FALSE,
        'description' => 'The Sharepoint file reference id.',
        'length' => 255,
      ],
    ];
    return [
      'columns' => $columns,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue(FieldDefinitionInterface $field_definition) {
    $values['value'] = mt_rand(1, 99999);
    return $values;
  }

}

==> linkit_sharepoint-1.0.1.tar.gz: linkit_sharepoint/src/Plugin/Field/FieldType/DocumentItem.php <==
<?php

namespace Drupal\linkit_sharepoint\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Defines the 'linkit_sharepoint_document' field type.
 *
 * @deprecated
 *
 * @FieldType(
 *   id = "linkit_sharepoint_document",
 *   label = @Translation("Deprecated: Sharepoint Document"),
 *   category = @Translation("General"),
 *   default_widget = "linkit_sharepoint_document",
 *   default_formatter = "linkit_sharepoint_document"
 * )
 */
class DocumentItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('value')->getValue();
    return $value === NULL || $value === '';
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['value'] = DataDefinition::create('string')
      ->setLabel(t('Text value'))
      ->setRequired(TRUE);
    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function getConstraints() {
    $constraints = parent::getConstraints();
    $constraint_manager = \Drupal::typedDataManager()->getValidationConstraintManager();

    $options['value']['Length']['max'] = 255;
    $constraints[] = $constraint_manager->create('ComplexData', $options);
    return $constraints;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    $columns = [
      'value' => [
        'type' => 'varchar',
        'not null' => FALSE,
        'description' => 'The Sharepoint file reference id.',
        'length' => 255,
      ],
    ];
    return [
      'columns' => $columns,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue(FieldDefinitionInterface $field_definition) {
    $values['value'] = mt_rand(1, 99999);
    return $values;
  }

}
